@@ -5,6 +5,7 @@ import logging
 import signal
 import subprocess
 import sys
+import time
 from pathlib import Path
 from typing import Optional
 
@@ -13,11 +14,6 @@ from rich.console import Console
 from rich.logging import RichHandler
 from rich.table import Table
 
-from .commands import audit as audit_cmd
-from .commands import custom_agents as custom_agents_cmd
-from .commands import feedback as feedback_cmd
-from .commands import summary as summary_cmd
-from .commands import telemetry as telemetry_cmd
 from devloop.agents import (
     AgentHealthMonitorAgent,
     FormatterAgent,
@@ -36,8 +32,24 @@ from devloop.core import (
     EventBus,
     context_store,
     event_store,
+    get_action_logger,
 )
 from devloop.core.amp_integration import check_agent_findings, show_agent_status
+from devloop.core.daemon_health import DaemonHealthCheck, check_daemon_health
+from devloop.core.error_handler import ErrorCode, ErrorSeverity, get_error_handler
+from devloop.core.error_notifier import ErrorNotifier
+from devloop.core.event_replayer import EventReplayer
+from devloop.core.transactional_io import initialize_transaction_system
+
+from .commands import audit as audit_cmd
+from .commands import custom_agents as custom_agents_cmd
+from .commands import feedback as feedback_cmd
+from .commands import marketplace as marketplace_cmd
+from .commands import metrics as metrics_cmd
+from .commands import release as release_cmd
+from .commands import summary as summary_cmd
+from .commands import telemetry as telemetry_cmd
+from .commands import tools as tools_cmd
 
 app = typer.Typer(
     help="DevLoop - Development workflow automation", add_completion=False
@@ -47,7 +59,11 @@ console = Console()
 app.add_typer(summary_cmd.app, name="summary")
 app.add_typer(custom_agents_cmd.app, name="custom")
 app.add_typer(feedback_cmd.app, name="feedback")
+app.add_typer(marketplace_cmd.app, name="agent")
+app.add_typer(metrics_cmd.app, name="metrics")
+app.add_typer(release_cmd.app, name="release")
 app.add_typer(telemetry_cmd.app, name="telemetry")
+app.add_typer(tools_cmd.app, name="tools")
 
 # Wrap Typer app to handle Click-based audit command
 # Note: We can't use add_typer with Click groups due to Typer version compatibility
@@ -55,19 +71,56 @@ _original_app = app
 
 
 class _WrappedApp:
-    """Wrapper app that intercepts Click commands before Typer processes them."""
+    """Wrapper app that intercepts Click commands before Typer processes them.
+
+    Also logs all CLI commands with optional Amp thread context for self-improvement agent.
+    """
 
     def __init__(self, typer_app):
         self.typer_app = typer_app
+        self.action_logger = get_action_logger()
 
     def __call__(self, *args, **kwargs):
-        """Handle command invocation."""
-        if len(sys.argv) > 1 and sys.argv[1] == "audit":
-            # Delegate to Click for audit command
-            audit_cmd.audit(sys.argv[2:], standalone_mode=False)
-            return
-        # Otherwise, run the Typer app normally
-        return self.typer_app(*args, **kwargs)
+        """Handle command invocation with action logging."""
+        start_time = time.time()
+        exit_code = None
+        error_message = None
+
+        try:
+            if len(sys.argv) > 1 and sys.argv[1] == "audit":
+                # Delegate to Click for audit command
+                audit_cmd.audit(sys.argv[2:], standalone_mode=False)
+                exit_code = 0
+                return
+
+            # Run the Typer app normally
+            return self.typer_app(*args, **kwargs)
+        except SystemExit as e:
+            exit_code = (
+                e.code if isinstance(e.code, int) else (0 if e.code is None else 1)
+            )
+            raise
+        except Exception as e:
+            exit_code = 1
+            error_message = str(e)
+            raise
+        finally:
+            # Log the command execution (even if it failed)
+            try:
+                duration_ms = int((time.time() - start_time) * 1000)
+                command = " ".join(sys.argv[1:]) if len(sys.argv) > 1 else "devloop"
+
+                self.action_logger.log_cli_command(
+                    command=command,
+                    exit_code=exit_code,
+                    duration_ms=duration_ms,
+                    error_message=error_message,
+                )
+            except Exception as log_error:
+                # Don't let logging errors break the CLI
+                logging.getLogger(__name__).debug(
+                    f"Failed to log CLI action: {log_error}"
+                )
 
     def __getattr__(self, name):
         """Delegate attribute access to the wrapped Typer app."""
@@ -119,6 +172,26 @@ def amp_context():
         )
 
 
+@app.command()
+def health():
+    """Show operational health status of agents."""
+    from pathlib import Path
+
+    from devloop.core.operational_health import OperationalHealthAnalyzer
+
+    devloop_dir = Path.cwd() / ".devloop"
+
+    if not devloop_dir.exists():
+        console.print(
+            "[yellow]No .devloop directory found. Start agents with 'devloop watch .' first.[/yellow]"
+        )
+        return
+
+    analyzer = OperationalHealthAnalyzer(devloop_dir)
+    report = analyzer.generate_health_report()
+    console.print(report)
+
+
 def setup_logging(verbose: bool = False):
     """Setup logging configuration."""
     level = logging.DEBUG if verbose else logging.INFO
@@ -258,6 +331,21 @@ def watch(
         asyncio.run(watch_async(path, config_path))
     except KeyboardInterrupt:
         console.print("\n[yellow]Shutting down...[/yellow]")
+    except Exception as e:
+        # Display critical startup errors with help
+        error_handler = get_error_handler()
+        error_notifier = ErrorNotifier(console)
+
+        if error_handler.has_critical_error():
+            critical_error = error_handler.get_critical_error()
+            if critical_error:
+                error_notifier.notify_startup_error(critical_error)
+                error_notifier.show_recovery_help(critical_error)
+        else:
+            # Unknown startup error
+            console.print(f"[red]✗ Startup failed: {e}[/red]")
+
+        sys.exit(1)
 
 
 async def _cleanup_old_data(context_store, event_store, interval_minutes: int = 15):
@@ -304,19 +392,50 @@ async def _cleanup_old_data(context_store, event_store, interval_minutes: int =
 
 async def watch_async(path: Path, config_path: Path | None):
     """Async watch implementation."""
-    # Load configuration
-    if config_path:
-        # Ensure it's a Path object and convert to string
-        config_manager = Config(str(Path(config_path).resolve()))
-    else:
-        # Default to project .devloop/agents.json
-        config_manager = Config(str((path / ".devloop" / "agents.json").resolve()))
-    config_dict = config_manager.load()
-    config = ConfigWrapper(config_dict)
+    # Initialize error handler
+    error_handler = get_error_handler()
+
+    # Load configuration with fail-fast on errors
+    try:
+        if config_path:
+            # Ensure it's a Path object and convert to string
+            config_manager = Config(str(Path(config_path).resolve()))
+        else:
+            # Default to project .devloop/agents.json
+            config_path_str = str((path / ".devloop" / "agents.json").resolve())
+            if not Path(config_path_str).exists():
+                error_handler.handle_startup_error(
+                    ErrorCode.CONFIG_NOT_FOUND,
+                    f"Configuration file not found: {config_path_str}",
+                    severity=ErrorSeverity.CRITICAL,
+                    details="Run 'devloop init' to create a default configuration.",
+                    suggested_action="devloop init",
+                )
+            config_manager = Config(config_path_str)
+
+        config_dict = config_manager.load()
+        config = ConfigWrapper(config_dict)
+    except ValueError as e:
+        error_handler.handle_startup_error(
+            ErrorCode.CONFIG_INVALID,
+            "Configuration validation failed",
+            exception=e,
+            severity=ErrorSeverity.CRITICAL,
+        )
+    except Exception as e:
+        error_handler.handle_startup_error(
+            ErrorCode.CONFIG_INVALID,
+            f"Failed to load configuration: {e}",
+            exception=e,
+            severity=ErrorSeverity.CRITICAL,
+        )
 
     # Create event bus
     event_bus = EventBus()
 
+    # Initialize transaction system (recovery and self-healing)
+    initialize_transaction_system(path / ".devloop")
+
     # Initialize context store
     context_store.context_dir = path / ".devloop" / "context"
     await context_store.initialize()
@@ -342,6 +461,10 @@ async def watch_async(path: Path, config_path: Path | None):
     # Start cleanup task (run every hour to remove old findings/events)
     cleanup_task = asyncio.create_task(_cleanup_old_data(context_store, event_store))
 
+    # Start daemon health check (heartbeat every 30 seconds)
+    health_check = DaemonHealthCheck(path, heartbeat_interval=30)
+    await health_check.start()
+
     # Create and register agents based on configuration
     if config.is_agent_enabled("linter"):
         linter_config = config.get_agent_config("linter") or {}
@@ -419,6 +542,24 @@ async def watch_async(path: Path, config_path: Path | None):
     for agent_name in agent_manager.list_agents():
         console.print(f"  • [cyan]{agent_name}[/cyan]")
 
+    # Replay missed events (event persistence and recovery)
+    replayer = EventReplayer(event_bus, agent_manager)
+    replay_stats = await replayer.replay_all_agents()
+
+    if replay_stats["total_replayed"] > 0:
+        console.print(
+            f"\n[cyan]Event Replay[/cyan]: Replayed {replay_stats['total_replayed']} missed events"
+        )
+        for agent_name, count in replay_stats["agents"].items():
+            if count > 0:
+                console.print(f"  • {agent_name}: {count} events")
+
+    if replay_stats["gaps"]:
+        console.print(
+            f"\n[yellow]⚠ Event Gaps Detected[/yellow]: {len(replay_stats['gaps'])} gaps in sequence"
+        )
+        console.print("[dim]Run 'devloop debug' for details[/dim]")
+
     console.print("\n[dim]Waiting for file changes... (Ctrl+C to stop)[/dim]\n")
 
     # Wait for shutdown signal
@@ -435,6 +576,7 @@ async def watch_async(path: Path, config_path: Path | None):
 
     # Stop everything
     cleanup_task.cancel()
+    await health_check.stop()
     await agent_manager.stop_all()
     await fs_collector.stop()
 
@@ -517,46 +659,134 @@ def init(
             config.save(config_file)
             console.print(f"\n[green]✓[/green] Created: {config_file}")
 
-    # Check for and manage AGENTS.md with Beads integration
+    # Check for and manage AGENTS.md with DevLoop template
     agents_md = path / "AGENTS.md"
+    devloop_template = (
+        Path(__file__).parent / "templates" / "devloop_agents_template.md"
+    )
+
+    # Legacy beads template (for backward compatibility)
     beads_template = claude_dir / "beads_template.md"
 
-    if beads_template.exists():
-        beads_content = beads_template.read_text()
+    # Check if AGENTS.md needs DevLoop content
+    needs_devloop_content = False
+    if agents_md.exists():
+        content = agents_md.read_text()
+        # Check for critical DevLoop sections
+        missing_sections = []
+        if "Task Management with Beads" not in content:
+            missing_sections.append("Beads task management")
+        if "NO MARKDOWN FILES FOR PLANNING" not in content:
+            missing_sections.append("No markdown files rule")
+        if (
+            "Secrets Management & Token Security" not in content
+            and "Secrets Management" not in content
+        ):
+            missing_sections.append("Token security")
+        if "Development Discipline" not in content:
+            missing_sections.append("Development discipline")
 
-        if agents_md.exists():
-            # Check if AGENTS.md already has Beads section
-            content = agents_md.read_text()
-            if "Task Management with Beads" not in content:
-                # Inject Beads section after first heading
+        needs_devloop_content = len(missing_sections) > 0
+
+        if needs_devloop_content:
+            # Copy template to .devloop for reference
+            devloop_template_copy = claude_dir / "devloop_agents_template.md"
+            if devloop_template.exists():
+                import shutil
+
+                shutil.copy(devloop_template, devloop_template_copy)
+
+                # Inject self-executing merge instruction directly into AGENTS.md
+                instruction_section = f"""
+
+---
+
+## 🔧 DevLoop Setup Required
+
+**⚠️ ACTION FOR AI ASSISTANT (Claude/Copilot):** This AGENTS.md is missing critical DevLoop sections.
+
+### Missing Sections:
+{chr(10).join(f'- {section}' for section in missing_sections)}
+
+### Instructions:
+
+Please complete this setup automatically:
+
+1. **Read the template**: `.devloop/devloop_agents_template.md`
+2. **Merge missing sections** into this AGENTS.md file
+3. **Follow merge guidelines** (see below)
+4. **Delete this entire section** (🔧 DevLoop Setup Required) after merging
+
+### Merge Guidelines:
+
+- ✅ **Do NOT duplicate** existing content - only add missing sections
+- ✅ **Preserve** all existing project-specific content
+- ✅ **Maintain** the existing document structure and headings
+- ✅ **Merge intelligently** - if a section partially exists, enhance it
+- ✅ **Respect** document flow - place sections in logical order
+
+### Required Sections:
+
+- ⚠️ Task Management with Beads (at the top, after title)
+- ⛔️ NO MARKDOWN FILES FOR PLANNING (absolute rules)
+- Development Discipline (commit/push requirements)
+- Secrets Management & Token Security
+- Absolute Rules for AI Agents
+
+**Template location:** `.devloop/devloop_agents_template.md`
+
+**Delete this section after successful merge.**
+
+---
+
+"""
+                # Insert at the beginning of the file (after title if present)
                 lines = content.split("\n")
                 insert_pos = 0
+
+                # Find first heading
                 for i, line in enumerate(lines):
-                    if line.startswith("# ") and i > 0:
+                    if line.startswith("# "):
                         insert_pos = i + 1
                         break
 
-                # Insert Beads section
+                # Insert the instruction
                 new_content = (
                     "\n".join(lines[:insert_pos])
-                    + "\n\n"
-                    + beads_content
-                    + "\n\n"
+                    + instruction_section
                     + "\n".join(lines[insert_pos:])
                 )
                 agents_md.write_text(new_content)
+
                 console.print(
-                    f"[green]✓[/green] Injected Beads section into {agents_md}"
+                    "\n[green]✓[/green] Injected DevLoop setup instructions into AGENTS.md"
                 )
-        else:
-            # Create AGENTS.md from template
+                console.print(
+                    f"[cyan]→[/cyan] Template copied to: {devloop_template_copy}"
+                )
+                console.print("\n[cyan]Next step:[/cyan]")
+                console.print(
+                    "  • Open this project in Claude Code/Amp - it will automatically merge the template!"
+                )
+    else:
+        # Create new AGENTS.md from devloop template
+        if devloop_template.exists():
+            import shutil
+
+            shutil.copy(devloop_template, agents_md)
+            console.print(
+                f"[green]✓[/green] Created: {agents_md} (from DevLoop template)"
+            )
+        elif beads_template.exists():
+            # Fallback to legacy beads template
+            beads_content = beads_template.read_text()
             template_header = """# Development Workflow
 
 This project uses background agents and Beads for task management.
 
 """
             agents_md.write_text(template_header + beads_content)
-            console.print(f"[green]✓[/green] Created: {agents_md}")
+            console.print(f"[green]✓[/green] Created: {agents_md} (legacy template)")
 
     # Handle Claude.md symlink for Claude code tools
     claude_md = path / "CLAUDE.md"
@@ -786,6 +1016,30 @@ def status():
     console.print(table)
 
 
+@app.command()
+def daemon_status(path: Path = typer.Argument(Path.cwd(), help="Project directory")):
+    """Check daemon health and status."""
+    health_result = check_daemon_health(path)
+
+    status = health_result["status"]
+    emoji = {"HEALTHY": "✅", "UNHEALTHY": "❌", "ERROR": "⚠️"}.get(status, "❓")
+
+    console.print(f"\n{emoji} Daemon Status: [bold]{status}[/bold]")
+    console.print(f"Message: {health_result['message']}")
+
+    if health_result.get("pid"):
+        console.print(f"PID: {health_result['pid']}")
+    if health_result.get("uptime_seconds"):
+        uptime = health_result["uptime_seconds"]
+        hours = int(uptime // 3600)
+        minutes = int((uptime % 3600) // 60)
+        console.print(f"Uptime: {hours}h {minutes}m")
+
+    if not health_result["healthy"]:
+        console.print("\n[yellow]Daemon may need to be restarted[/yellow]")
+        console.print("Run: [cyan]devloop stop && devloop watch .[/cyan]")
+
+
 @app.command()
 def stop(path: Path = typer.Argument(Path.cwd(), help="Project directory")):
     """Stop the background devloop daemon."""
